summaryrefslogtreecommitdiffstats
path: root/src/k9mainw.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/k9mainw.cpp')
-rw-r--r--src/k9mainw.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/k9mainw.cpp b/src/k9mainw.cpp
index f2e685c..24a9552 100644
--- a/src/k9mainw.cpp
+++ b/src/k9mainw.cpp
@@ -27,11 +27,11 @@
#include "kpushbutton.h"
/*
* Constructs a MainDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-MainDlg::MainDlg( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+MainDlg::MainDlg( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "MainDlg" );
@@ -27,11 +27,11 @@
#include "kpushbutton.h"
/*
- * Constructs a MainDlg as a child of 'tqparent', with the
+ * Constructs a MainDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/